==> wpackagist-plugin-styles-layouts-material-design-4.1.zip: includes/multiselect.php <==
<?php

/***************************************** for multiselect inputs ****************************************************************************/
//var_dump($field->type);
if ( in_array( $field->type, $multiselect_fields )  ) {
	$multiselect_classes_types = array( 'ginput_container_multiselect' );

	$content_xpath = new DomXPath($dom);

	$select_containers = $content_xpath->query("//*[contains(concat(' ', normalize-space(@class), ' '), ' ginput_container_multiselect ')]");

	$validation_errors = $content_xpath->query("//*[contains(concat(' ', normalize-space(@class), ' '), ' validation_message ')]");

	foreach ( $validation_errors as $validation_error ) {
		$validation_error->setAttribute( 'class', $validation_error->getAttribute( 'class' ) . ' mdc-text-field-helper-text mdc-text-field-helper-text--persistent mdc-text-field-helper-text--validation-msg' );
	}
	foreach( $select_containers as $select_container ){
		$selects = $select_container->getElementsByTagName( 'select' );
		foreach( $selects as $select ){
			$select->setAttribute( 'class', $select->getAttribute('class') . ' mdc-list' );
			$options = $select->getElementsByTagName( 'option' );
			foreach( $options as $option ){
				$option->setAttribute( 'class', $option->getAttribute('class') . ' mdc-list-item' );
			}
		}
	}

	$is_valid_input_field = false;
		if ( $is_valid_input_field ) {
			$selects = $dom->getElementsByTagName( 'select' );
			foreach ( $selects as $select ) {
				$select_classes = $select->getAttribute( 'class' );
				$select->setAttribute( 'class', $select_classes . ' mdc-list mdc-list--dense' );
				$select->setAttribute( 'size', '5' );
				$options = $select->getElementsByTagName( 'option' );
				foreach ( $options as $option ) {
					$option->setAttribute( 'class', $option->getAttribute( 'class' ) . ' mdc-list-item' );
				}

				if ( strpos( $select_classes, 'large' ) !== false ) {
					$field_size_class = 'stla_material_large';
				}
				else if ( strpos( $select_classes, 'medium' ) !== false ) {
					$field_size_class = 'stla_material_medium';
				}
				else {
					$field_size_class = 'stla_material_small';
				}
			}
			$div->setAttribute( 'class', $div->getAttribute( 'class' ) . ' ' . $field_size_class );
		}
		

	$content = utf8_decode($dom->saveHTML($dom->documentElement));
}

==> wpackagist-plugin-styles-layouts-material-design-5.0.zip: includes/multiselect.php <==
<?php

/***************************************** for multiselect inputs ****************************************************************************/
//var_dump($field->type);
if ( in_array( $field->type, $multiselect_fields )  ) {
	$multiselect_classes_types = array( 'ginput_container_multiselect' );

	$content_xpath = new DomXPath($dom);

	$select_containers = $content_xpath->query("//*[contains(concat(' ', normalize-space(@class), ' '), ' ginput_container_multiselect ')]");

	
	$field_labels =  $content_xpath->query("//*[contains(concat(' ', normalize-space(@class), ' '), ' gfield_label ')]");
	// set class on field labels.
	foreach( $field_labels as $field_label ){
		$label_class = $field_label->getAttribute( 'class' );

		$field_label->setAttribute( 'class', $label_class. ' mdc-typography--subtitle1' );
	}


	$validation_errors = $content_xpath->query("//*[contains(concat(' ', normalize-space(@class), ' '), ' validation_message ')]");

	foreach ( $validation_errors as $validation_error ) {
		$validation_error->setAttribute( 'class', $validation_error->getAttribute( 'class' ) . ' mdc-text-field-helper-text mdc-text-field-helper-text--persistent mdc-text-field-helper-text--validation-msg' );
	}
	foreach( $select_containers as $select_container ){
		$selects = $select_container->getElementsByTagName( 'select' );
		foreach( $selects as $select ){
			$select->setAttribute( 'class', $select->getAttribute('class') . ' mdc-list' );
			$options = $select->getElementsByTagName( 'option' );
			foreach( $options as $option ){
				$option->setAttribute( 'class', $option->getAttribute('class') . ' mdc-list-item' );
			}
		}
	}

	$is_valid_input_field = false;
		if ( $is_valid_input_field ) {
			$selects = $dom->getElementsByTagName( 'select' );
			foreach ( $selects as $select ) {
				$select_classes = $select->getAttribute( 'class' );
				$select->setAttribute( 'class', $select_classes . ' mdc-list mdc-list--dense' );
				$select->setAttribute( 'size', '5' );
				$options = $select->getElementsByTagName( 'option' );
				foreach ( $options as $option ) {
					$option->setAttribute( 'class', $option->getAttribute( 'class' ) . ' mdc-list-item' );
				}

				if ( strpos( $select_classes, 'large' ) !== false ) {
					$field_size_class = 'stla_material_large';
				}
				else if ( strpos( $select_classes, 'medium' ) !== false ) {
					$field_size_class = 'stla_material_medium';
				}
				else {
					$field_size_class = 'stla_material_small';
				}
			}
			$div->setAttribute( 'class', $div->getAttribute( 'class' ) . ' ' . $field_size_class );
		}
		

	$content = utf8_decode($dom->saveHTML($dom->documentElement));
}
